import { FileBase, IResolver, Project } from 'projen';
type WithRequired<T, K extends keyof T> = T & {
    [P in K]-?: T[P];
};
export type OptWithRequired = WithRequired<PyProjectTomlOptions, 'packageName' | 'version'>;
/**
 * pyproject.toml synthetisation
 */
export declare class PyProjectTomlFile extends FileBase {
    private readonly opts;
    constructor(project: Project, opts?: PyProjectTomlOptions);
    protected synthesizeContent(_resolver: IResolver): string | undefined;
}
export declare const resolvePackageName: (projectName: string, pyProjectOpts?: PyProjectTomlOptions) => string;
export interface PyProjectTomlOptions {
    /**
     * Name of the python package. E.g. "my_python_package".
     * Must only consist of alphanumeric characters and underscores.
     * @default Name of the directory
     */
    readonly packageName?: string;
    /**
     * Author's name
     */
    readonly authorName?: string;
    /**
     * Author's e-mail
     */
    readonly authorEmail?: string;
    /**
     * Version of the package.
     */
    readonly version?: string;
    /**
     * Keywords to add to the package.
     */
    readonly keywords?: string[];
    /**
     * List of maintainers of the package.
     */
    /**
     * A short description of the package.
     */
    readonly description?: string;
    /**
     * A URL to the website of the project.
     */
    readonly homepage?: string;
    /**
     * README file.
     */
    readonly readme?: string;
    /**
     * License file
     */
    readonly licenseFile?: string;
    /**
     * Python version required to run this package
     */
    readonly requiresPython?: string;
    /**
     * A list of PyPI trove classifiers that describe the project.
     *
     * @see https://pypi.org/classifiers/
     */
    readonly classifiers?: string[];
}
export {};
