import { Project, ProjectOptions } from 'projen';
import { Build0Options } from './build';
import { LintOptions } from './lint';
import { TestOptions } from './test';
import { TaskOptionsTarget } from './tasks';
/**
 * Python project with basic configurations for linting, testing, building etc
 * @pjid python_basic
 */
export declare class PythonBasicProject extends Project {
    constructor(options: PythonBasicOptions);
    /**
     * Add a runtime dependency in format [package-name][==version]
     * E.g: `addDep('package==1.0.0')`
     */
    addDep(packageNameVersion: string): void;
    /**
     * Add a development dependency in format [package-name][==version]
     */
    addDevDep(packageNameVersion: string): void;
    private addDependency;
}
export interface PythonBasicOptions extends ProjectOptions, Build0Options, TaskOptionsTarget {
    /**
     * Package dependencies in format `['package==1.0.0', 'package2==2.0.0']`
     */
    readonly deps?: string[];
    /**
     * Development dependencies in format `['package==1.0.0', 'package2==2.0.0']`
     */
    readonly devDeps?: string[];
    /**
     * Create sample code and test (if dir doesn't exist yet)
     * @default true
     */
    readonly sample?: boolean;
    /**
     * Linting configurations such as rules selected etc
     */
    readonly lint?: LintOptions;
    /**
     * Test configurations
     */
    readonly test?: TestOptions;
}
